diff --git a/MyTracks/res/layout/upload_result.xml b/MyTracks/res/layout/upload_result.xml
index a0610a4c7..65f20a9a5 100644
--- a/MyTracks/res/layout/upload_result.xml
+++ b/MyTracks/res/layout/upload_result.xml
@@ -18,20 +18,16 @@ limitations under the License.
android:layout_height="fill_parent"
android:layout_margin="8dp"
android:layout_width="fill_parent" >
-
-
-
-
-
-
-
+ android:text="@string/send_google_maps"
+ style="@android:style/TextAppearance.DeviceDefault.Medium" />
+ android:text="@string/send_google_maps_url"
+ style="@android:style/TextAppearance.DeviceDefault.Small" />
-
-
-
-
-
-
+ android:text="@string/send_google_fusion_tables"
+ style="@android:style/TextAppearance.DeviceDefault.Medium" />
+ android:text="@string/send_google_fusion_tables_url"
+ style="@android:style/TextAppearance.DeviceDefault.Small" />
-
-
-
-
-
-
+ android:text="@string/send_google_docs"
+ style="@android:style/TextAppearance.DeviceDefault.Medium" />
+ android:text="@string/send_google_docs_url"
+ style="@android:style/TextAppearance.DeviceDefault.Small" />
-
-
-
+ android:text="@string/send_google_success_footer"
+ style="@android:style/TextAppearance.DeviceDefault.Small" />
+ android:text="@string/send_google_error"
+ style="@android:style/TextAppearance.DeviceDefault.Medium" />
-
\ No newline at end of file
diff --git a/MyTracks/res/layout/upload_service_chooser.xml b/MyTracks/res/layout/upload_service_chooser.xml
index 599f5f421..c4cc68a35 100644
--- a/MyTracks/res/layout/upload_service_chooser.xml
+++ b/MyTracks/res/layout/upload_service_chooser.xml
@@ -17,89 +17,75 @@ limitations under the License.
-
-
-
-
+ android:text="@string/send_google_maps"
+ style="@android:style/TextAppearance.DeviceDefault.Medium" />
-
-
-
-
+ android:text="@string/send_google_new_map"
+ style="@android:style/TextAppearance.DeviceDefault.Medium" />
+ android:text="@string/send_google_existing_map"
+ style="@android:style/TextAppearance.DeviceDefault.Medium" />
-
-
-
+ android:text="@string/send_google_fusion_tables"
+ style="@android:style/TextAppearance.DeviceDefault.Medium" />
-
-
+ android:text="@string/send_google_docs"
+ style="@android:style/TextAppearance.DeviceDefault.Medium" />
-
\ No newline at end of file
diff --git a/MyTracks/res/menu/search_only.xml b/MyTracks/res/menu/search_only.xml
index ccf072255..44cd456e8 100644
--- a/MyTracks/res/menu/search_only.xml
+++ b/MyTracks/res/menu/search_only.xml
@@ -15,12 +15,9 @@ See the License for the specific language governing permissions and
limitations under the License.
-->
\ No newline at end of file
diff --git a/MyTracks/res/values/strings.xml b/MyTracks/res/values/strings.xml
index dfedfd7a7..32d60d49c 100644
--- a/MyTracks/res/values/strings.xml
+++ b/MyTracks/res/values/strings.xml
@@ -643,15 +643,12 @@ limitations under the License.
+ %1$s: host name, 'm.google.com'">
By using Google\'s mobile products and services ("Services"), you agree to be bound by a) the
YouTube Terms of Use (%1$s/tos_youtube) for YouTube-related Services, b) the Google Maps Terms
- and Conditions (%2$s/tos_maps) for mapping, local and location-based Services, c) the Google
- Books Terms of Service (%3$s/tos_books) for Books-related Services, and e) the Google Terms of
- Service (%4$s/utos) for all other Services, as updated from time to time.
+ and Conditions (%1$s/tos_maps) for mapping, local and location-based Services, c) the Google
+ Books Terms of Service (%1$s/tos_books) for Books-related Services, and e) the Google Terms of
+ Service (%1$s/utos) for all other Services, as updated from time to time.
@@ -1290,7 +1287,7 @@ limitations under the License.
- You did not select any service. No data is sent.
+ You did not select any service. The track was not sent.
{
@Override
protected Boolean doInBackground(Void... params) {
try {
- FileUtils fileUtils = new FileUtils();
- if (!fileUtils.isSdCardAvailable()) {
+ if (!FileUtils.isSdCardAvailable()) {
return false;
}
diff --git a/MyTracks/src/com/google/android/apps/mytracks/MapActivity.java b/MyTracks/src/com/google/android/apps/mytracks/MapActivity.java
index 115e015ef..7214687d0 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/MapActivity.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/MapActivity.java
@@ -250,7 +250,7 @@ public class MapActivity extends com.google.android.maps.MapActivity
return PlayTrackUtils.createInstallEarthDialog(this);
case DIALOG_DELETE_CURRENT_ID:
return DialogUtils.createConfirmationDialog(this,
- getString(R.string.track_list_delete_track_confirm_message),
+ R.string.track_list_delete_track_confirm_message,
new DialogInterface.OnClickListener() {
@Override
public void onClick(DialogInterface dialog, int which) {
diff --git a/MyTracks/src/com/google/android/apps/mytracks/MyTracks.java b/MyTracks/src/com/google/android/apps/mytracks/MyTracks.java
index 3fd22109a..37ab619bd 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/MyTracks.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/MyTracks.java
@@ -32,8 +32,8 @@ import com.google.android.apps.mytracks.services.TrackRecordingServiceConnection
import com.google.android.apps.mytracks.util.AnalyticsUtils;
import com.google.android.apps.mytracks.util.ApiAdapterFactory;
import com.google.android.apps.mytracks.util.EulaUtils;
-import com.google.android.apps.mytracks.util.SystemUtils;
import com.google.android.apps.mytracks.util.UriUtils;
+import com.google.android.maps.mytracks.BuildConfig;
import com.google.android.maps.mytracks.R;
import android.app.Activity;
@@ -73,7 +73,7 @@ public class MyTracks extends TabActivity implements OnTouchListener {
private static final int DIALOG_CHECK_UNITS_ID = 1;
private static final String CHECK_UNITS_PREFERENCE_FILE = "checkunits";
private static final String CHECK_UNITS_PREFERENCE_KEY = "checkunits.checked";
-
+
private TrackDataHub dataHub;
/**
@@ -140,7 +140,7 @@ public class MyTracks extends TabActivity implements OnTouchListener {
protected void onCreate(Bundle savedInstanceState) {
Log.d(TAG, "MyTracks.onCreate");
super.onCreate(savedInstanceState);
- if (!SystemUtils.isRelease(this)) {
+ if (BuildConfig.DEBUG) {
ApiAdapterFactory.getApiAdapter().enableStrictMode();
}
@@ -153,7 +153,7 @@ public class MyTracks extends TabActivity implements OnTouchListener {
serviceConnection = new TrackRecordingServiceConnection(this, serviceBindCallback);
setVolumeControlStream(TextToSpeech.Engine.DEFAULT_STREAM);
-
+
// Show the action bar (or nothing at all).
ApiAdapterFactory.getApiAdapter().showActionBar(this);
diff --git a/MyTracks/src/com/google/android/apps/mytracks/SettingsActivity.java b/MyTracks/src/com/google/android/apps/mytracks/SettingsActivity.java
index 17d41c844..06c0cacf1 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/SettingsActivity.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/SettingsActivity.java
@@ -30,7 +30,6 @@ import com.google.android.maps.mytracks.R;
import android.app.Dialog;
import android.bluetooth.BluetoothAdapter;
import android.content.DialogInterface;
-import android.content.DialogInterface.OnClickListener;
import android.content.Intent;
import android.content.SharedPreferences;
import android.content.SharedPreferences.Editor;
@@ -178,7 +177,7 @@ public class SettingsActivity extends PreferenceActivity {
switch (id) {
case DIALOG_CONFIRM_RESET_ID:
return DialogUtils.createConfirmationDialog(
- this, getString(R.string.settings_reset_confirm_message), new OnClickListener() {
+ this, R.string.settings_reset_confirm_message, new DialogInterface.OnClickListener() {
@Override
public void onClick(DialogInterface dialog, int button) {
onResetPreferencesConfirmed();
@@ -186,8 +185,8 @@ public class SettingsActivity extends PreferenceActivity {
});
case DIALOG_CONFIRM_ACCESS_ID:
return DialogUtils.createConfirmationDialog(this,
- getString(R.string.settings_sharing_allow_access_confirm_message),
- new OnClickListener() {
+ R.string.settings_sharing_allow_access_confirm_message,
+ new DialogInterface.OnClickListener() {
@Override
public void onClick(DialogInterface dialog, int button) {
CheckBoxPreference pref = (CheckBoxPreference) findPreference(
@@ -196,8 +195,9 @@ public class SettingsActivity extends PreferenceActivity {
}
});
case DIALOG_CONFIRM_RESTORE_ID:
- return DialogUtils.createConfirmationDialog(
- this, getString(R.string.settings_backup_restore_confirm_message), new OnClickListener() {
+ return DialogUtils.createConfirmationDialog(this,
+ R.string.settings_backup_restore_confirm_message,
+ new DialogInterface.OnClickListener() {
@Override
public void onClick(DialogInterface dialog, int which) {
startActivity(new Intent(SettingsActivity.this, RestoreChooserActivity.class));
diff --git a/MyTracks/src/com/google/android/apps/mytracks/TrackList.java b/MyTracks/src/com/google/android/apps/mytracks/TrackList.java
index 14971c751..0695071fa 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/TrackList.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/TrackList.java
@@ -324,6 +324,17 @@ public class TrackList extends ListActivity
getMenuInflater().inflate(R.menu.search_only, menu);
return true;
}
+
+ @Override
+ public boolean onOptionsItemSelected(MenuItem item) {
+ switch (item.getItemId()) {
+ case R.id.menu_search:
+ onSearchRequested();
+ return true;
+ default:
+ return super.onOptionsItemSelected(item);
+ }
+ }
@Override
protected Dialog onCreateDialog(int id) {
@@ -354,8 +365,7 @@ public class TrackList extends ListActivity
.create();
case DIALOG_DELETE_ALL_ID:
return DialogUtils.createConfirmationDialog(this,
- getString(R.string.track_list_delete_all_confirm_message),
- new DialogInterface.OnClickListener() {
+ R.string.track_list_delete_all_confirm_message, new DialogInterface.OnClickListener() {
@Override
public void onClick(DialogInterface dialog, int which) {
MyTracksProviderUtils.Factory.get(TrackList.this).deleteAllTracks();
@@ -369,7 +379,7 @@ public class TrackList extends ListActivity
});
case DIALOG_DELETE_CURRENT_ID:
return DialogUtils.createConfirmationDialog(this,
- getString(R.string.track_list_delete_track_confirm_message),
+ R.string.track_list_delete_track_confirm_message,
new DialogInterface.OnClickListener() {
@Override
public void onClick(DialogInterface dialog, int which) {
@@ -389,11 +399,6 @@ public class TrackList extends ListActivity
}
}
- /* Callback from menu/search_only.xml */
- public void onSearch(@SuppressWarnings("unused") MenuItem i) {
- onSearchRequested();
- }
-
private void updateButtonsEnabled() {
View deleteAll = findViewById(R.id.tracklist_btn_delete_all);
View exportAll = findViewById(R.id.tracklist_btn_export_all);
diff --git a/MyTracks/src/com/google/android/apps/mytracks/WaypointsList.java b/MyTracks/src/com/google/android/apps/mytracks/WaypointsList.java
index 08819ffa2..7ef0dae1f 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/WaypointsList.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/WaypointsList.java
@@ -203,31 +203,34 @@ public class WaypointsList extends ListActivity implements View.OnClickListener
@Override
protected Dialog onCreateDialog(int id) {
- switch (id) {
- case DIALOG_DELETE_CURRENT_ID:
- return DialogUtils.createConfirmationDialog(this,
- getString(R.string.marker_list_delete_marker_confirm_message),
- new DialogInterface.OnClickListener() {
- @Override
- public void onClick(DialogInterface dialog, int which) {
- providerUtils.deleteWaypoint(
- selectedWaypointId, new DescriptionGeneratorImpl(WaypointsList.this));
- }
- });
- default:
- return null;
+ if (id != DIALOG_DELETE_CURRENT_ID) {
+ return null;
}
+ return DialogUtils.createConfirmationDialog(this,
+ R.string.marker_list_delete_marker_confirm_message, new DialogInterface.OnClickListener() {
+ @Override
+ public void onClick(DialogInterface dialog, int which) {
+ providerUtils.deleteWaypoint(
+ selectedWaypointId, new DescriptionGeneratorImpl(WaypointsList.this));
+ }
+ });
}
-
+
@Override
public boolean onCreateOptionsMenu(Menu menu) {
getMenuInflater().inflate(R.menu.search_only, menu);
return true;
}
-
- /* Callback from menu/search_only.xml */
- public void onSearch(@SuppressWarnings("unused") MenuItem i) {
- onSearchRequested();
+
+ @Override
+ public boolean onOptionsItemSelected(MenuItem item) {
+ switch (item.getItemId()) {
+ case R.id.menu_search:
+ onSearchRequested();
+ return true;
+ default:
+ return super.onOptionsItemSelected(item);
+ }
}
@Override
diff --git a/MyTracks/src/com/google/android/apps/mytracks/WelcomeActivity.java b/MyTracks/src/com/google/android/apps/mytracks/WelcomeActivity.java
index ff32fdc44..2a1f5f42d 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/WelcomeActivity.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/WelcomeActivity.java
@@ -61,7 +61,6 @@ public class WelcomeActivity extends Activity {
View view = getLayoutInflater().inflate(R.layout.about, null);
TextView aboutVersion = (TextView) view.findViewById(R.id.about_version);
aboutVersion.setText(SystemUtils.getMyTracksVersion(this));
-
return new AlertDialog.Builder(this)
.setCancelable(true)
.setNegativeButton(R.string.about_license, new DialogInterface.OnClickListener() {
diff --git a/MyTracks/src/com/google/android/apps/mytracks/io/backup/BackupActivity.java b/MyTracks/src/com/google/android/apps/mytracks/io/backup/BackupActivity.java
index 4f55a9ccf..fb4f12de2 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/io/backup/BackupActivity.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/io/backup/BackupActivity.java
@@ -58,19 +58,16 @@ public class BackupActivity extends Activity {
@Override
protected Dialog onCreateDialog(int id) {
- switch (id) {
- case DIALOG_PROGRESS_ID:
- return DialogUtils.createSpinnerProgressDialog(this,
- getString(R.string.settings_backup_now_progress_message),
- new DialogInterface.OnCancelListener() {
- @Override
- public void onCancel(DialogInterface dialog) {
- finish();
- }
- });
- default:
- return null;
+ if (id != DIALOG_PROGRESS_ID) {
+ return null;
}
+ return DialogUtils.createSpinnerProgressDialog(
+ this, R.string.settings_backup_now_progress_message, new DialogInterface.OnCancelListener() {
+ @Override
+ public void onCancel(DialogInterface dialog) {
+ finish();
+ }
+ });
}
/**
diff --git a/MyTracks/src/com/google/android/apps/mytracks/io/backup/BackupAsyncTask.java b/MyTracks/src/com/google/android/apps/mytracks/io/backup/BackupAsyncTask.java
index 3ef19ad31..fd0675640 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/io/backup/BackupAsyncTask.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/io/backup/BackupAsyncTask.java
@@ -53,7 +53,7 @@ public class BackupAsyncTask extends AsyncTask {
*/
public BackupAsyncTask(BackupActivity backupActivity) {
this.backupActivity = backupActivity;
- this.externalFileBackup = new ExternalFileBackup(backupActivity, new FileUtils());
+ this.externalFileBackup = new ExternalFileBackup(backupActivity);
success = false;
completed = false;
messageId = R.string.sd_card_error_write_file;
@@ -80,9 +80,7 @@ public class BackupAsyncTask extends AsyncTask {
@Override
protected Boolean doInBackground(Void... params) {
- FileUtils fileUtils = new FileUtils();
-
- if (!fileUtils.isSdCardAvailable()) {
+ if (!FileUtils.isSdCardAvailable()) {
messageId = R.string.sd_card_error_no_storage;
return false;
}
diff --git a/MyTracks/src/com/google/android/apps/mytracks/io/backup/ExternalFileBackup.java b/MyTracks/src/com/google/android/apps/mytracks/io/backup/ExternalFileBackup.java
index 68a0aea09..7fe2b3c2b 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/io/backup/ExternalFileBackup.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/io/backup/ExternalFileBackup.java
@@ -65,11 +65,9 @@ class ExternalFileBackup {
private static final int COMPRESSION_LEVEL = 8;
private final Context context;
- private final FileUtils fileUtils;
- public ExternalFileBackup(Context context, FileUtils fileUtils) {
+ public ExternalFileBackup(Context context) {
this.context = context;
- this.fileUtils = fileUtils;
}
/**
@@ -87,12 +85,12 @@ class ExternalFileBackup {
* @param create whether to try creating the directory if it doesn't exist
*/
private File getBackupsDirectory(boolean create) {
- String dirName = fileUtils.buildExternalDirectoryPath(BACKUPS_SUBDIR);
+ String dirName = FileUtils.buildExternalDirectoryPath(BACKUPS_SUBDIR);
final File dir = new File(dirName);
Log.d(Constants.TAG, "Dir: " + dir.getAbsolutePath());
if (create) {
// Try to create - if that fails, return null
- return fileUtils.ensureDirectoryExists(dir) ? dir : null;
+ return FileUtils.ensureDirectoryExists(dir) ? dir : null;
} else {
// Return it if it already exists, otherwise return null
return dir.isDirectory() ? dir : null;
diff --git a/MyTracks/src/com/google/android/apps/mytracks/io/backup/RestoreActivity.java b/MyTracks/src/com/google/android/apps/mytracks/io/backup/RestoreActivity.java
index 43528a63b..b00aa3fe3 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/io/backup/RestoreActivity.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/io/backup/RestoreActivity.java
@@ -71,19 +71,16 @@ public class RestoreActivity extends Activity {
@Override
protected Dialog onCreateDialog(int id) {
- switch (id) {
- case DIALOG_PROGRESS_ID:
- return DialogUtils.createSpinnerProgressDialog(this,
- getString(R.string.settings_backup_restore_progress_message),
- new DialogInterface.OnCancelListener() {
- @Override
- public void onCancel(DialogInterface dialog) {
- finish();
- }
- });
- default:
- return null;
+ if (id != DIALOG_PROGRESS_ID) {
+ return null;
}
+ return DialogUtils.createSpinnerProgressDialog(this,
+ R.string.settings_backup_restore_progress_message, new DialogInterface.OnCancelListener() {
+ @Override
+ public void onCancel(DialogInterface dialog) {
+ finish();
+ }
+ });
}
/**
diff --git a/MyTracks/src/com/google/android/apps/mytracks/io/backup/RestoreAsyncTask.java b/MyTracks/src/com/google/android/apps/mytracks/io/backup/RestoreAsyncTask.java
index 23917d521..009c0d44f 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/io/backup/RestoreAsyncTask.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/io/backup/RestoreAsyncTask.java
@@ -16,7 +16,6 @@
package com.google.android.apps.mytracks.io.backup;
-import com.google.android.apps.mytracks.util.FileUtils;
import com.google.android.maps.mytracks.R;
import android.os.AsyncTask;
@@ -57,7 +56,7 @@ public class RestoreAsyncTask extends AsyncTask {
public RestoreAsyncTask(RestoreActivity restoreActivity, Date date) {
this.restoreActivity = restoreActivity;
this.date = date;
- this.externalFileBackup = new ExternalFileBackup(restoreActivity, new FileUtils());
+ this.externalFileBackup = new ExternalFileBackup(restoreActivity);
success = false;
completed = false;
messageId = R.string.sd_card_error_read_file;
diff --git a/MyTracks/src/com/google/android/apps/mytracks/io/backup/RestoreChooserActivity.java b/MyTracks/src/com/google/android/apps/mytracks/io/backup/RestoreChooserActivity.java
index 8b5fc81c7..fc1ba9bce 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/io/backup/RestoreChooserActivity.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/io/backup/RestoreChooserActivity.java
@@ -24,8 +24,6 @@ import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
-import android.content.DialogInterface.OnCancelListener;
-import android.content.DialogInterface.OnClickListener;
import android.content.Intent;
import android.os.Bundle;
import android.widget.Toast;
@@ -55,11 +53,10 @@ public class RestoreChooserActivity extends Activity {
protected void onCreate(Bundle savedInstanceState) {
super.onCreate(savedInstanceState);
- FileUtils fileUtils = new FileUtils();
- ExternalFileBackup externalFileBackup = new ExternalFileBackup(this, fileUtils);
+ ExternalFileBackup externalFileBackup = new ExternalFileBackup(this);
// Get the list of existing backups
- if (!fileUtils.isSdCardAvailable()) {
+ if (!FileUtils.isSdCardAvailable()) {
Toast.makeText(this, R.string.sd_card_error_no_storage, Toast.LENGTH_LONG).show();
finish();
return;
@@ -91,32 +88,30 @@ public class RestoreChooserActivity extends Activity {
@Override
protected Dialog onCreateDialog(int id) {
- switch (id) {
- case DIALOG_CHOOSER_ID:
- String items[] = new String[backupDates.length];
- for (int i = 0; i < backupDates.length; i++) {
- items[i] = StringUtils.formatDateTime(this, backupDates[i].getTime());
- }
- return new AlertDialog.Builder(this)
- .setCancelable(true)
- .setItems(items, new OnClickListener() {
- @Override
- public void onClick(DialogInterface dialog, int which) {
- startActivity(new Intent(RestoreChooserActivity.this, RestoreActivity.class)
- .putExtra(RestoreActivity.EXTRA_DATE, backupDates[which].getTime()));
- finish();
- }
- })
- .setOnCancelListener(new OnCancelListener() {
- @Override
- public void onCancel(DialogInterface dialog) {
- finish();
- }
- })
- .setTitle(R.string.settings_backup_restore_select_title)
- .create();
- default:
- return null;
+ if (id != DIALOG_CHOOSER_ID) {
+ return null;
}
+ String items[] = new String[backupDates.length];
+ for (int i = 0; i < backupDates.length; i++) {
+ items[i] = StringUtils.formatDateTime(this, backupDates[i].getTime());
+ }
+ return new AlertDialog.Builder(this)
+ .setCancelable(true)
+ .setItems(items, new DialogInterface.OnClickListener() {
+ @Override
+ public void onClick(DialogInterface dialog, int which) {
+ startActivity(new Intent(RestoreChooserActivity.this, RestoreActivity.class).putExtra(
+ RestoreActivity.EXTRA_DATE, backupDates[which].getTime()));
+ finish();
+ }
+ })
+ .setOnCancelListener(new DialogInterface.OnCancelListener() {
+ @Override
+ public void onCancel(DialogInterface dialog) {
+ finish();
+ }
+ })
+ .setTitle(R.string.settings_backup_restore_select_title)
+ .create();
}
}
diff --git a/MyTracks/src/com/google/android/apps/mytracks/io/file/SaveActivity.java b/MyTracks/src/com/google/android/apps/mytracks/io/file/SaveActivity.java
index 1c0b4ed73..bc31d16b5 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/io/file/SaveActivity.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/io/file/SaveActivity.java
@@ -28,8 +28,6 @@ import android.app.AlertDialog;
import android.app.Dialog;
import android.app.ProgressDialog;
import android.content.DialogInterface;
-import android.content.DialogInterface.OnCancelListener;
-import android.content.DialogInterface.OnClickListener;
import android.content.Intent;
import android.net.Uri;
import android.os.Bundle;
@@ -102,7 +100,7 @@ public class SaveActivity extends Activity {
}
if (shareTrack || playTrack) {
// Save to the temp directory
- String dirName = new FileUtils().buildExternalDirectoryPath(
+ String dirName = FileUtils.buildExternalDirectoryPath(
trackFileFormat.getExtension(), "tmp");
trackWriter.setDirectory(new File(dirName));
}
@@ -121,9 +119,8 @@ public class SaveActivity extends Activity {
protected Dialog onCreateDialog(int id) {
switch (id) {
case DIALOG_PROGRESS_ID:
- progressDialog = DialogUtils.createHorizontalProgressDialog(this,
- getString(R.string.sd_card_progress_message),
- new DialogInterface.OnCancelListener() {
+ progressDialog = DialogUtils.createHorizontalProgressDialog(
+ this, R.string.sd_card_progress_message, new DialogInterface.OnCancelListener() {
@Override
public void onCancel(DialogInterface dialog) {
saveAsyncTask.cancel(true);
@@ -137,14 +134,14 @@ public class SaveActivity extends Activity {
.setIcon(success
? android.R.drawable.ic_dialog_info : android.R.drawable.ic_dialog_alert)
.setMessage(messageId)
- .setOnCancelListener(new OnCancelListener() {
+ .setOnCancelListener(new DialogInterface.OnCancelListener() {
@Override
public void onCancel(DialogInterface dialog) {
dialog.dismiss();
onPostResultDialog();
}
})
- .setPositiveButton(R.string.generic_ok, new OnClickListener() {
+ .setPositiveButton(R.string.generic_ok, new DialogInterface.OnClickListener() {
@Override
public void onClick(DialogInterface dialog, int arg1) {
dialog.dismiss();
diff --git a/MyTracks/src/com/google/android/apps/mytracks/io/file/TrackWriterImpl.java b/MyTracks/src/com/google/android/apps/mytracks/io/file/TrackWriterImpl.java
index 76517544b..977ea8692 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/io/file/TrackWriterImpl.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/io/file/TrackWriterImpl.java
@@ -52,7 +52,6 @@ class TrackWriterImpl implements TrackWriter {
private final MyTracksProviderUtils providerUtils;
private final Track track;
private final TrackFormatWriter writer;
- private final FileUtils fileUtils;
private boolean success = false;
private int errorMessage = -1;
private File directory = null;
@@ -66,7 +65,6 @@ class TrackWriterImpl implements TrackWriter {
this.providerUtils = providerUtils;
this.track = track;
this.writer = writer;
- this.fileUtils = new FileUtils();
}
@Override
@@ -175,7 +173,7 @@ class TrackWriterImpl implements TrackWriter {
}
// Make sure the file doesn't exist yet (possibly by changing the filename)
- String fileName = fileUtils.buildUniqueFileName(
+ String fileName = FileUtils.buildUniqueFileName(
directory, track.getName(), writer.getExtension());
if (fileName == null) {
Log.e(Constants.TAG,
@@ -200,16 +198,16 @@ class TrackWriterImpl implements TrackWriter {
protected boolean canWriteFile() {
if (directory == null) {
String dirName =
- fileUtils.buildExternalDirectoryPath(writer.getExtension());
+ FileUtils.buildExternalDirectoryPath(writer.getExtension());
directory = newFile(dirName);
}
- if (!fileUtils.isSdCardAvailable()) {
+ if (!FileUtils.isSdCardAvailable()) {
Log.i(Constants.TAG, "Could not find SD card.");
errorMessage = R.string.sd_card_error_no_storage;
return false;
}
- if (!fileUtils.ensureDirectoryExists(directory)) {
+ if (!FileUtils.ensureDirectoryExists(directory)) {
Log.i(Constants.TAG, "Could not create export directory.");
errorMessage = R.string.sd_card_error_create_dir;
return false;
diff --git a/MyTracks/src/com/google/android/apps/mytracks/io/maps/ChooseMapActivity.java b/MyTracks/src/com/google/android/apps/mytracks/io/maps/ChooseMapActivity.java
index c864e01de..62112474c 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/io/maps/ChooseMapActivity.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/io/maps/ChooseMapActivity.java
@@ -25,8 +25,6 @@ import android.app.Activity;
import android.app.AlertDialog;
import android.app.Dialog;
import android.content.DialogInterface;
-import android.content.DialogInterface.OnCancelListener;
-import android.content.DialogInterface.OnClickListener;
import android.content.Intent;
import android.graphics.Color;
import android.os.Bundle;
@@ -122,7 +120,7 @@ public class ChooseMapActivity extends Activity {
switch (id) {
case DIALOG_PROGRESS_ID:
return DialogUtils.createSpinnerProgressDialog(
- this, getString(R.string.maps_list_progress_message), new DialogInterface.OnCancelListener() {
+ this, R.string.maps_list_progress_message, new DialogInterface.OnCancelListener() {
@Override
public void onCancel(DialogInterface dialog) {
asyncTask.cancel(true);
@@ -134,13 +132,13 @@ public class ChooseMapActivity extends Activity {
.setCancelable(true)
.setIcon(android.R.drawable.ic_dialog_alert)
.setMessage(R.string.maps_list_error)
- .setOnCancelListener(new OnCancelListener() {
+ .setOnCancelListener(new DialogInterface.OnCancelListener() {
@Override
public void onCancel(DialogInterface dialog) {
finish();
}
})
- .setPositiveButton(R.string.generic_ok, new OnClickListener() {
+ .setPositiveButton(R.string.generic_ok, new DialogInterface.OnClickListener() {
@Override
public void onClick(DialogInterface dialog, int arg1) {
finish();
diff --git a/MyTracks/src/com/google/android/apps/mytracks/io/sendtogoogle/AbstractSendActivity.java b/MyTracks/src/com/google/android/apps/mytracks/io/sendtogoogle/AbstractSendActivity.java
index 6a094d1e1..b21aee1d9 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/io/sendtogoogle/AbstractSendActivity.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/io/sendtogoogle/AbstractSendActivity.java
@@ -71,21 +71,18 @@ public abstract class AbstractSendActivity extends Activity {
@Override
protected Dialog onCreateDialog(int id) {
- switch (id) {
- case DIALOG_PROGRESS_ID:
- progressDialog = DialogUtils.createHorizontalProgressDialog(this,
- getString(R.string.send_google_progress_message, getServiceName()),
- new DialogInterface.OnCancelListener() {
- @Override
- public void onCancel(DialogInterface dialog) {
- asyncTask.cancel(true);
- startNextActivity(false, true);
- }
- });
- return progressDialog;
- default:
- return null;
+ if (id != DIALOG_PROGRESS_ID) {
+ return null;
}
+ progressDialog = DialogUtils.createHorizontalProgressDialog(
+ this, R.string.send_google_progress_message, new DialogInterface.OnCancelListener() {
+ @Override
+ public void onCancel(DialogInterface dialog) {
+ asyncTask.cancel(true);
+ startNextActivity(false, true);
+ }
+ }, getServiceName());
+ return progressDialog;
}
/**
diff --git a/MyTracks/src/com/google/android/apps/mytracks/io/sendtogoogle/AccountChooserActivity.java b/MyTracks/src/com/google/android/apps/mytracks/io/sendtogoogle/AccountChooserActivity.java
index 1e078aefe..9b769ef1a 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/io/sendtogoogle/AccountChooserActivity.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/io/sendtogoogle/AccountChooserActivity.java
@@ -135,49 +135,56 @@ public class AccountChooserActivity extends Activity {
.setTitle(R.string.send_google_no_account_title)
.create();
case DIALOG_CHOOSER_ID:
- String[] choices = new String[accounts.length];
- for (int i = 0; i < accounts.length; i++) {
- choices[i] = accounts[i].name;
- }
- return new AlertDialog.Builder(this)
- .setCancelable(true)
- .setNegativeButton(R.string.generic_cancel, new DialogInterface.OnClickListener() {
- public void onClick(DialogInterface dialog, int which) {
- finish();
- }
- })
- .setOnCancelListener(new DialogInterface.OnCancelListener() {
- @Override
- public void onCancel(DialogInterface dialog) {
- finish();
- }
- })
- .setPositiveButton(R.string.generic_ok, new DialogInterface.OnClickListener() {
- public void onClick(DialogInterface dialog, int which) {
- Account account = accounts[selectedAccountIndex];
- SharedPreferences sharedPreferences = getSharedPreferences(
- Constants.SETTINGS_NAME, Context.MODE_PRIVATE);
- Editor editor = sharedPreferences.edit();
- editor.putString(getString(R.string.preferred_account_key), account.name);
- ApiAdapterFactory.getApiAdapter().applyPreferenceChanges(editor);
-
- sendRequest.setAccount(account);
- getPermission(MapsConstants.SERVICE_NAME, sendRequest.isSendMaps(), mapsCallback);
- }
- })
- .setSingleChoiceItems(
- choices, selectedAccountIndex, new DialogInterface.OnClickListener() {
- @Override
- public void onClick(DialogInterface dialog, int which) {
- selectedAccountIndex = which;
- }
- })
- .setTitle(R.string.send_google_choose_account_title)
- .create();
+ return createChooserDialog();
default:
return null;
}
}
+
+ /**
+ * Creates a chooser dialog.
+ */
+ private Dialog createChooserDialog() {
+ String[] choices = new String[accounts.length];
+ for (int i = 0; i < accounts.length; i++) {
+ choices[i] = accounts[i].name;
+ }
+ return new AlertDialog.Builder(this)
+ .setCancelable(true)
+ .setNegativeButton(R.string.generic_cancel, new DialogInterface.OnClickListener() {
+ public void onClick(DialogInterface dialog, int which) {
+ finish();
+ }
+ })
+ .setOnCancelListener(new DialogInterface.OnCancelListener() {
+ @Override
+ public void onCancel(DialogInterface dialog) {
+ finish();
+ }
+ })
+ .setPositiveButton(R.string.generic_ok, new DialogInterface.OnClickListener() {
+ public void onClick(DialogInterface dialog, int which) {
+ Account account = accounts[selectedAccountIndex];
+ SharedPreferences sharedPreferences = getSharedPreferences(
+ Constants.SETTINGS_NAME, Context.MODE_PRIVATE);
+ Editor editor = sharedPreferences.edit();
+ editor.putString(getString(R.string.preferred_account_key), account.name);
+ ApiAdapterFactory.getApiAdapter().applyPreferenceChanges(editor);
+
+ sendRequest.setAccount(account);
+ getPermission(MapsConstants.SERVICE_NAME, sendRequest.isSendMaps(), mapsCallback);
+ }
+ })
+ .setSingleChoiceItems(
+ choices, selectedAccountIndex, new DialogInterface.OnClickListener() {
+ @Override
+ public void onClick(DialogInterface dialog, int which) {
+ selectedAccountIndex = which;
+ }
+ })
+ .setTitle(R.string.send_google_choose_account_title)
+ .create();
+ }
private PermissionCallback spreadsheetsCallback = new PermissionCallback() {
@Override
diff --git a/MyTracks/src/com/google/android/apps/mytracks/io/sendtogoogle/UploadResultActivity.java b/MyTracks/src/com/google/android/apps/mytracks/io/sendtogoogle/UploadResultActivity.java
index 5f12ee9c5..f77a33f4b 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/io/sendtogoogle/UploadResultActivity.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/io/sendtogoogle/UploadResultActivity.java
@@ -80,100 +80,94 @@ public class UploadResultActivity extends Activity {
@Override
protected Dialog onCreateDialog(int id) {
- switch (id) {
- case DIALOG_RESULT_ID:
- View view = getLayoutInflater().inflate(R.layout.upload_result, null);
+ if (id != DIALOG_RESULT_ID) {
+ return null;
+ }
+ View view = getLayoutInflater().inflate(R.layout.upload_result, null);
- LinearLayout mapsResult = (LinearLayout) view.findViewById(R.id.upload_result_maps_result);
- LinearLayout fusionTablesResult = (LinearLayout) view.findViewById(
- R.id.upload_result_fusion_tables_result);
- LinearLayout docsResult = (LinearLayout) view.findViewById(R.id.upload_result_docs_result);
+ LinearLayout mapsResult = (LinearLayout) view.findViewById(R.id.upload_result_maps_result);
+ LinearLayout fusionTablesResult = (LinearLayout) view.findViewById(
+ R.id.upload_result_fusion_tables_result);
+ LinearLayout docsResult = (LinearLayout) view.findViewById(R.id.upload_result_docs_result);
- ImageView mapsResultIcon = (ImageView) view.findViewById(
- R.id.upload_result_maps_result_icon);
- ImageView fusionTablesResultIcon = (ImageView) view.findViewById(
- R.id.upload_result_fusion_tables_result_icon);
- ImageView docsResultIcon = (ImageView) view.findViewById(
- R.id.upload_result_docs_result_icon);
+ ImageView mapsResultIcon = (ImageView) view.findViewById(R.id.upload_result_maps_result_icon);
+ ImageView fusionTablesResultIcon = (ImageView) view.findViewById(
+ R.id.upload_result_fusion_tables_result_icon);
+ ImageView docsResultIcon = (ImageView) view.findViewById(R.id.upload_result_docs_result_icon);
- TextView successFooter = (TextView) view.findViewById(R.id.upload_result_success_footer);
- TextView errorFooter = (TextView) view.findViewById(R.id.upload_result_error_footer);
+ TextView successFooter = (TextView) view.findViewById(R.id.upload_result_success_footer);
+ TextView errorFooter = (TextView) view.findViewById(R.id.upload_result_error_footer);
- boolean hasError = false;
- if (!sendRequest.isSendMaps()) {
- mapsResult.setVisibility(View.GONE);
- } else {
- if (!sendRequest.isMapsSuccess()) {
- mapsResultIcon.setImageResource(R.drawable.failure);
- mapsResultIcon.setContentDescription(getString(R.string.generic_error_title));
- hasError = true;
- }
- }
-
- if (!sendRequest.isSendFusionTables()) {
- fusionTablesResult.setVisibility(View.GONE);
- } else {
- if (!sendRequest.isFusionTablesSuccess()) {
- fusionTablesResultIcon.setImageResource(R.drawable.failure);
- fusionTablesResultIcon.setContentDescription(getString(R.string.generic_error_title));
- hasError = true;
- }
- }
-
- if (!sendRequest.isSendDocs()) {
- docsResult.setVisibility(View.GONE);
- } else {
- if (!sendRequest.isDocsSuccess()) {
- docsResultIcon.setImageResource(R.drawable.failure);
- docsResultIcon.setContentDescription(getString(R.string.generic_error_title));
- hasError = true;
- }
- }
-
- if (hasError) {
- successFooter.setVisibility(View.GONE);
- } else {
- errorFooter.setVisibility(View.GONE);
- }
-
- AlertDialog.Builder builder = new AlertDialog.Builder(this)
- .setCancelable(true)
- .setIcon(hasError ? android.R.drawable.ic_dialog_alert
- : android.R.drawable.ic_dialog_info)
- .setOnCancelListener(new DialogInterface.OnCancelListener() {
- @Override
- public void onCancel(DialogInterface dialog) {
- finish();
- }
- })
- .setPositiveButton(R.string.generic_ok, new DialogInterface.OnClickListener() {
- @Override
- public void onClick(DialogInterface dialog, int which) {
- if (!sendRequest.isShowAll() && shareUrl != null) {
- startShareUrlActivity(shareUrl);
- }
- finish();
- }
- })
- .setTitle(hasError ? R.string.generic_error_title : R.string.generic_success_title)
- .setView(view);
-
- // Add a Share URL button if showing all the options and a shareUrl
- // exists
- if (sendRequest.isShowAll() && shareUrl != null) {
- builder.setNegativeButton(getString(R.string.send_google_result_share_url),
- new DialogInterface.OnClickListener() {
- @Override
- public void onClick(DialogInterface dialog, int which) {
- startShareUrlActivity(shareUrl);
- finish();
- }
- });
- }
- return builder.create();
- default:
- return null;
+ boolean hasError = false;
+ if (!sendRequest.isSendMaps()) {
+ mapsResult.setVisibility(View.GONE);
+ } else {
+ if (!sendRequest.isMapsSuccess()) {
+ mapsResultIcon.setImageResource(R.drawable.failure);
+ mapsResultIcon.setContentDescription(getString(R.string.generic_error_title));
+ hasError = true;
+ }
}
+
+ if (!sendRequest.isSendFusionTables()) {
+ fusionTablesResult.setVisibility(View.GONE);
+ } else {
+ if (!sendRequest.isFusionTablesSuccess()) {
+ fusionTablesResultIcon.setImageResource(R.drawable.failure);
+ fusionTablesResultIcon.setContentDescription(getString(R.string.generic_error_title));
+ hasError = true;
+ }
+ }
+
+ if (!sendRequest.isSendDocs()) {
+ docsResult.setVisibility(View.GONE);
+ } else {
+ if (!sendRequest.isDocsSuccess()) {
+ docsResultIcon.setImageResource(R.drawable.failure);
+ docsResultIcon.setContentDescription(getString(R.string.generic_error_title));
+ hasError = true;
+ }
+ }
+
+ if (hasError) {
+ successFooter.setVisibility(View.GONE);
+ } else {
+ errorFooter.setVisibility(View.GONE);
+ }
+
+ AlertDialog.Builder builder = new AlertDialog.Builder(this)
+ .setCancelable(true)
+ .setIcon(hasError ? android.R.drawable.ic_dialog_alert : android.R.drawable.ic_dialog_info)
+ .setOnCancelListener(new DialogInterface.OnCancelListener() {
+ @Override
+ public void onCancel(DialogInterface dialog) {
+ finish();
+ }
+ })
+ .setPositiveButton(R.string.generic_ok, new DialogInterface.OnClickListener() {
+ @Override
+ public void onClick(DialogInterface dialog, int which) {
+ if (!sendRequest.isShowAll() && shareUrl != null) {
+ startShareUrlActivity(shareUrl);
+ }
+ finish();
+ }
+ })
+ .setTitle(hasError ? R.string.generic_error_title : R.string.generic_success_title)
+ .setView(view);
+
+ // Add a Share URL button if showing all the options and a shareUrl exists
+ if (sendRequest.isShowAll() && shareUrl != null) {
+ builder.setNegativeButton(
+ R.string.send_google_result_share_url, new DialogInterface.OnClickListener() {
+ @Override
+ public void onClick(DialogInterface dialog, int which) {
+ startShareUrlActivity(shareUrl);
+ finish();
+ }
+ });
+ }
+ return builder.create();
}
/**
diff --git a/MyTracks/src/com/google/android/apps/mytracks/io/sendtogoogle/UploadServiceChooserActivity.java b/MyTracks/src/com/google/android/apps/mytracks/io/sendtogoogle/UploadServiceChooserActivity.java
index 0e0433cb7..c2703b016 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/io/sendtogoogle/UploadServiceChooserActivity.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/io/sendtogoogle/UploadServiceChooserActivity.java
@@ -78,77 +78,73 @@ public class UploadServiceChooserActivity extends Activity {
@Override
protected Dialog onCreateDialog(int id) {
- switch (id) {
- case DIALOG_CHOOSER_ID:
- View view = getLayoutInflater().inflate(R.layout.upload_service_chooser, null);
-
- mapsTableRow = (TableRow) view.findViewById(R.id.send_google_maps_row);
- fusionTablesTableRow = (TableRow) view.findViewById(R.id.send_google_fusion_tables_row);
- docsTableRow = (TableRow) view.findViewById(R.id.send_google_docs_row);
-
- mapsCheckBox = (CheckBox) view.findViewById(R.id.send_google_maps);
- fusionTablesCheckBox = (CheckBox) view.findViewById(R.id.send_google_fusion_tables);
- docsCheckBox = (CheckBox) view.findViewById(R.id.send_google_docs);
-
- mapsOptionTableRow = (TableRow) view.findViewById(R.id.send_google_maps_option_row);
- newMapRadioButton = (RadioButton) view.findViewById(R.id.send_google_new_map);
- existingMapRadioButton = (RadioButton) view.findViewById(R.id.send_google_existing_map);
-
- // Setup checkboxes
- OnCheckedChangeListener checkBoxListener = new OnCheckedChangeListener() {
- public void onCheckedChanged(CompoundButton button, boolean checked) {
- updateStateBySelection();
- }
- };
- mapsCheckBox.setOnCheckedChangeListener(checkBoxListener);
- fusionTablesCheckBox.setOnCheckedChangeListener(checkBoxListener);
- docsCheckBox.setOnCheckedChangeListener(checkBoxListener);
-
- // Setup initial state
- initState();
-
- // Update state based on sendRequest
- updateStateBySendRequest();
-
- // Update state based on current selection
- updateStateBySelection();
-
- alertDialog = new AlertDialog.Builder(this)
- .setCancelable(true)
- .setNegativeButton(R.string.generic_cancel, new DialogInterface.OnClickListener() {
- @Override
- public void onClick(DialogInterface dialog, int which) {
- finish();
- }
- })
- .setOnCancelListener(new DialogInterface.OnCancelListener() {
- @Override
- public void onCancel(DialogInterface d) {
- finish();
- }
- })
- .setPositiveButton(
- R.string.send_google_send_now, new DialogInterface.OnClickListener() {
-
- @Override
- public void onClick(DialogInterface dialog, int which) {
- saveState();
- if (sendMaps() || sendFusionTables() || sendDocs()) {
- startNextActivity();
- } else {
- Toast.makeText(UploadServiceChooserActivity.this,
- R.string.send_google_no_service_selected, Toast.LENGTH_LONG).show();
- finish();
- }
- }
- })
- .setTitle(R.string.send_google_title)
- .setView(view)
- .create();
- return alertDialog;
- default:
- return null;
+ if (id != DIALOG_CHOOSER_ID) {
+ return null;
}
+ View view = getLayoutInflater().inflate(R.layout.upload_service_chooser, null);
+
+ mapsTableRow = (TableRow) view.findViewById(R.id.send_google_maps_row);
+ fusionTablesTableRow = (TableRow) view.findViewById(R.id.send_google_fusion_tables_row);
+ docsTableRow = (TableRow) view.findViewById(R.id.send_google_docs_row);
+
+ mapsCheckBox = (CheckBox) view.findViewById(R.id.send_google_maps);
+ fusionTablesCheckBox = (CheckBox) view.findViewById(R.id.send_google_fusion_tables);
+ docsCheckBox = (CheckBox) view.findViewById(R.id.send_google_docs);
+
+ mapsOptionTableRow = (TableRow) view.findViewById(R.id.send_google_maps_option_row);
+ newMapRadioButton = (RadioButton) view.findViewById(R.id.send_google_new_map);
+ existingMapRadioButton = (RadioButton) view.findViewById(R.id.send_google_existing_map);
+
+ // Setup checkboxes
+ OnCheckedChangeListener checkBoxListener = new OnCheckedChangeListener() {
+ public void onCheckedChanged(CompoundButton button, boolean checked) {
+ updateStateBySelection();
+ }
+ };
+ mapsCheckBox.setOnCheckedChangeListener(checkBoxListener);
+ fusionTablesCheckBox.setOnCheckedChangeListener(checkBoxListener);
+ docsCheckBox.setOnCheckedChangeListener(checkBoxListener);
+
+ // Setup initial state
+ initState();
+
+ // Update state based on sendRequest
+ updateStateBySendRequest();
+
+ // Update state based on current selection
+ updateStateBySelection();
+
+ alertDialog = new AlertDialog.Builder(this)
+ .setCancelable(true)
+ .setNegativeButton(R.string.generic_cancel, new DialogInterface.OnClickListener() {
+ @Override
+ public void onClick(DialogInterface dialog, int which) {
+ finish();
+ }
+ })
+ .setOnCancelListener(new DialogInterface.OnCancelListener() {
+ @Override
+ public void onCancel(DialogInterface d) {
+ finish();
+ }
+ })
+ .setPositiveButton(R.string.send_google_send_now, new DialogInterface.OnClickListener() {
+ @Override
+ public void onClick(DialogInterface dialog, int which) {
+ saveState();
+ if (sendMaps() || sendFusionTables() || sendDocs()) {
+ startNextActivity();
+ } else {
+ Toast.makeText(UploadServiceChooserActivity.this,
+ R.string.send_google_no_service_selected, Toast.LENGTH_LONG).show();
+ finish();
+ }
+ }
+ })
+ .setTitle(R.string.send_google_title)
+ .setView(view)
+ .create();
+ return alertDialog;
}
/**
diff --git a/MyTracks/src/com/google/android/apps/mytracks/services/RemoveTempFilesService.java b/MyTracks/src/com/google/android/apps/mytracks/services/RemoveTempFilesService.java
index 0a36b2e66..9866aca3f 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/services/RemoveTempFilesService.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/services/RemoveTempFilesService.java
@@ -91,10 +91,7 @@ public class RemoveTempFilesService extends Service {
}
private void cleanTempDirectory(String name) {
- FileUtils fileUtils = new FileUtils();
- String dirName = fileUtils.buildExternalDirectoryPath(name, "tmp");
- File dir = new File(dirName);
- cleanTempDirectory(dir);
+ cleanTempDirectory(new File(FileUtils.buildExternalDirectoryPath(name, "tmp")));
}
/**
diff --git a/MyTracks/src/com/google/android/apps/mytracks/services/TrackRecordingServiceConnection.java b/MyTracks/src/com/google/android/apps/mytracks/services/TrackRecordingServiceConnection.java
index f646ab1cd..58bfb95a2 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/services/TrackRecordingServiceConnection.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/services/TrackRecordingServiceConnection.java
@@ -18,6 +18,7 @@ package com.google.android.apps.mytracks.services;
import static com.google.android.apps.mytracks.Constants.TAG;
import com.google.android.apps.mytracks.util.SystemUtils;
+import com.google.android.maps.mytracks.BuildConfig;
import android.content.ComponentName;
import android.content.Context;
@@ -157,7 +158,7 @@ public class TrackRecordingServiceConnection {
Log.i(TAG, "Binding to the service");
Intent intent = new Intent(context, TrackRecordingService.class);
- int flags = SystemUtils.isRelease(context) ? 0 : Context.BIND_DEBUG_UNBIND;
+ int flags = BuildConfig.DEBUG ? Context.BIND_DEBUG_UNBIND : 0;
context.bindService(intent, serviceConnection, flags);
}
diff --git a/MyTracks/src/com/google/android/apps/mytracks/services/sensors/ant/AntSrmBridgeSensorManager.java b/MyTracks/src/com/google/android/apps/mytracks/services/sensors/ant/AntSrmBridgeSensorManager.java
index 1006e4a6b..2a16fb743 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/services/sensors/ant/AntSrmBridgeSensorManager.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/services/sensors/ant/AntSrmBridgeSensorManager.java
@@ -23,7 +23,7 @@ import com.dsi.ant.exception.AntInterfaceException;
import com.google.android.apps.mytracks.Constants;
import com.google.android.apps.mytracks.content.Sensor;
import com.google.android.apps.mytracks.util.ApiAdapterFactory;
-import com.google.android.apps.mytracks.util.SystemUtils;
+import com.google.android.maps.mytracks.BuildConfig;
import com.google.android.maps.mytracks.R;
import android.content.Context;
@@ -32,7 +32,7 @@ import android.util.Log;
/**
* A sensor manager to the PC7 SRM ANT+ bridge.
- *
+ *
* @author Sandor Dornbush
* @author Umran Abdulla
*/
@@ -54,15 +54,15 @@ public class AntSrmBridgeSensorManager extends AntSensorManager {
private static final int INDEX_MESSAGE_SPEED = 5;
private static final int INDEX_MESSAGE_CADENCE = 7;
private static final int INDEX_MESSAGE_BPM = 8;
-
+
private static final int MSG_INITIAL = 5;
private static final int MSG_DATA = 6;
-
+
private short deviceNumber;
public AntSrmBridgeSensorManager(Context context) {
super(context);
-
+
Log.i(TAG, "new ANT SRM Bridge Sensor Manager created");
deviceNumber = WILDCARD;
@@ -77,15 +77,15 @@ public class AntSrmBridgeSensorManager extends AntSensorManager {
}
Log.i(TAG, "Will pair with device: " + deviceNumber);
}
-
-
+
+
@Override
protected boolean handleMessage(byte messageId, byte[] messageData) {
if (super.handleMessage(messageId, messageData)) {
return true;
}
-
- if (!SystemUtils.isRelease(context)) {
+
+ if (BuildConfig.DEBUG) {
Log.d(TAG, "Received ANT msg: " + AntUtils.antMessageToString(messageId) + "(" + messageId + ")");
}
@@ -100,7 +100,7 @@ public class AntSrmBridgeSensorManager extends AntSensorManager {
return true;
}
-
+
/**
* Decode an ant device message.
* @param messageData The byte array received from the device.
@@ -132,10 +132,10 @@ public class AntSrmBridgeSensorManager extends AntSensorManager {
}
setSensorState(Sensor.SensorState.CONNECTED);
-
+
int messageType = antMessage[INDEX_MESSAGE_TYPE] & 0xFF;
Log.d(TAG, "Received message-type=" + messageType);
-
+
switch (messageType) {
case MSG_INITIAL:
break;
@@ -149,7 +149,7 @@ public class AntSrmBridgeSensorManager extends AntSensorManager {
{
int messageId = msg[INDEX_MESSAGE_ID] & 0xFF;
Log.d(TAG, "Received message-id=" + messageId);
-
+
int powerVal = (((msg[INDEX_MESSAGE_POWER] & 0xFF) << 8) |
(msg[INDEX_MESSAGE_POWER+1] & 0xFF));
@SuppressWarnings("unused")
@@ -158,12 +158,12 @@ public class AntSrmBridgeSensorManager extends AntSensorManager {
int cadenceVal = (msg[INDEX_MESSAGE_CADENCE] & 0xFF);
int bpmVal = (msg[INDEX_MESSAGE_BPM] & 0xFF);
long time = System.currentTimeMillis();
-
- Sensor.SensorData.Builder power =
+
+ Sensor.SensorData.Builder power =
Sensor.SensorData.newBuilder()
.setValue(powerVal)
.setState(Sensor.SensorState.SENDING);
-
+
/*
* Although speed is available from the SRM Bridge, MyTracks doesn't use the value, and
* computes speed from the GPS location data.
@@ -171,12 +171,12 @@ public class AntSrmBridgeSensorManager extends AntSensorManager {
// Sensor.SensorData.Builder speed = Sensor.SensorData.newBuilder().setValue(speedVal).setState(
// Sensor.SensorState.SENDING);
- Sensor.SensorData.Builder cadence =
+ Sensor.SensorData.Builder cadence =
Sensor.SensorData.newBuilder()
.setValue(cadenceVal)
.setState(Sensor.SensorState.SENDING);
- Sensor.SensorData.Builder bpm =
+ Sensor.SensorData.Builder bpm =
Sensor.SensorData.newBuilder()
.setValue(bpmVal)
.setState(Sensor.SensorState.SENDING);
@@ -189,7 +189,7 @@ public class AntSrmBridgeSensorManager extends AntSensorManager {
.setHeartRate(bpm)
.build();
}
-
+
void handleChannelId(byte[] rawMessage) {
AntChannelIdMessage message = new AntChannelIdMessage(rawMessage);
deviceNumber = message.getDeviceNumber();
@@ -203,12 +203,12 @@ public class AntSrmBridgeSensorManager extends AntSensorManager {
}
private void handleMessageResponse(byte[] rawMessage) {
- AntChannelResponseMessage message =
+ AntChannelResponseMessage message =
new AntChannelResponseMessage(rawMessage);
- if (!SystemUtils.isRelease(context)) {
+ if (BuildConfig.DEBUG) {
Log.d(TAG, "Received ANT Response: " + AntUtils.antMessageToString(message.getMessageId()) +
"(" + message.getMessageId() + ")" +
- ", Code: " + AntUtils.antEventToStr(message.getMessageCode()) +
+ ", Code: " + AntUtils.antEventToStr(message.getMessageCode()) +
"(" + message.getMessageCode() + ")");
}
switch (message.getMessageId()) {
diff --git a/MyTracks/src/com/google/android/apps/mytracks/util/EulaUtils.java b/MyTracks/src/com/google/android/apps/mytracks/util/EulaUtils.java
index 078136391..c2d7ed541 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/util/EulaUtils.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/util/EulaUtils.java
@@ -35,6 +35,7 @@ public class EulaUtils {
// Accepting Google mobile terms of service
private static final String EULA_PREFERENCE_KEY = "eula.google_mobile_tos_accepted";
+ // Google's mobile page
private static final String HOST_NAME = "m.google.com";
private EulaUtils() {}
@@ -56,7 +57,7 @@ public class EulaUtils {
public static String getEulaMessage(Context context) {
return context.getString(R.string.eula_date)
+ "\n\n"
- + context.getString(R.string.eula_body, HOST_NAME, HOST_NAME, HOST_NAME, HOST_NAME)
+ + context.getString(R.string.eula_body, HOST_NAME)
+ "\n\n"
+ context.getString(R.string.eula_footer, HOST_NAME)
+ "\n\n"
diff --git a/MyTracks/src/com/google/android/apps/mytracks/util/FileUtils.java b/MyTracks/src/com/google/android/apps/mytracks/util/FileUtils.java
index 99ce45838..11d7ff5da 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/util/FileUtils.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/util/FileUtils.java
@@ -29,20 +29,46 @@ import java.io.File;
*/
public class FileUtils {
+ private FileUtils() {}
+
/**
* The maximum FAT32 path length. See the FAT32 spec at
* http://msdn.microsoft.com/en-us/windows/hardware/gg463080
*/
@VisibleForTesting
static final int MAX_FAT32_PATH_LENGTH = 260;
-
+
+ /**
+ * Returns whether the SD card is available.
+ */
+ public static boolean isSdCardAvailable() {
+ return Environment.MEDIA_MOUNTED.equals(Environment.getExternalStorageState());
+ }
+
+ /**
+ * Ensures the given directory exists by creating it and its parents if
+ * necessary.
+ *
+ * @return whether the directory exists (either already existed or was
+ * successfully created)
+ */
+ public static boolean ensureDirectoryExists(File dir) {
+ if (dir.exists() && dir.isDirectory()) {
+ return true;
+ }
+ if (dir.mkdirs()) {
+ return true;
+ }
+ return false;
+ }
+
/**
* Builds a path inside the My Tracks directory in the SD card.
*
* @param components the path components inside the mytracks directory
* @return the full path to the destination
*/
- public String buildExternalDirectoryPath(String... components) {
+ public static String buildExternalDirectoryPath(String... components) {
StringBuilder dirNameBuilder = new StringBuilder();
dirNameBuilder.append(Environment.getExternalStorageDirectory());
dirNameBuilder.append(File.separatorChar);
@@ -54,33 +80,6 @@ public class FileUtils {
return dirNameBuilder.toString();
}
- /**
- * Returns whether the SD card is available.
- */
- public boolean isSdCardAvailable() {
- return Environment.MEDIA_MOUNTED.equals(
- Environment.getExternalStorageState());
- }
-
- /**
- * Ensures the given directory exists by creating it and its parents if
- * necessary.
- *
- * @return whether the directory exists (either already existed or was
- * successfully created)
- */
- public boolean ensureDirectoryExists(File dir) {
- if (dir.exists() && dir.isDirectory()) {
- return true;
- }
-
- if (dir.mkdirs()) {
- return true;
- }
-
- return false;
- }
-
/**
* Builds a filename with the given base name (prefix) and the given
* extension, possibly adding a suffix to ensure the file doesn't exist.
@@ -90,8 +89,8 @@ public class FileUtils {
* @param extension the file's extension
* @return the complete file name, without the directory
*/
- public synchronized String buildUniqueFileName(File directory,
- String fileBaseName, String extension) {
+ public static synchronized String buildUniqueFileName(
+ File directory, String fileBaseName, String extension) {
return buildUniqueFileName(directory, fileBaseName, extension, 0);
}
@@ -105,7 +104,8 @@ public class FileUtils {
* @param suffix the first numeric suffix to try to use, or 0 for none
* @return the complete filename, without the directory
*/
- private String buildUniqueFileName(File directory, String base, String extension, int suffix) {
+ private static String buildUniqueFileName(
+ File directory, String base, String extension, int suffix) {
String suffixName = "";
if (suffix > 0) {
suffixName += "(" + Integer.toString(suffix) + ")";
@@ -115,8 +115,8 @@ public class FileUtils {
String baseName = sanitizeFileName(base);
baseName = truncateFileName(directory, baseName, suffixName);
String fullName = baseName + suffixName;
-
- if (!fileExists(directory, fullName)) {
+
+ if (!new File(directory, fullName).exists()) {
return fullName;
}
return buildUniqueFileName(directory, base, extension, suffix + 1);
@@ -131,7 +131,7 @@ public class FileUtils {
* @param name name
*/
@VisibleForTesting
- String sanitizeFileName(String name) {
+ static String sanitizeFileName(String name) {
StringBuffer buffer = new StringBuffer(name.length());
for (int i = 0; i < name.length(); i++) {
int codePoint = name.codePointAt(i);
@@ -145,13 +145,13 @@ public class FileUtils {
String result = buffer.toString();
return result.replaceAll("_+", "_");
}
-
+
/**
* Returns true if it is a special FAT32 character.
- *
+ *
* @param character the character
*/
- private boolean isSpecialFat32(char character) {
+ private static boolean isSpecialFat32(char character) {
switch (character) {
case '$':
case '%':
@@ -191,8 +191,8 @@ public class FileUtils {
* @param suffix suffix
*/
@VisibleForTesting
- String truncateFileName(File directory, String name, String suffix) {
- // 1 at the end accounts for the FAT32 filename trailing NUL character
+ static String truncateFileName(File directory, String name, String suffix) {
+ // 1 at the end accounts for the FAT32 filename trailing NUL character
int requiredLength = directory.getPath().length() + suffix.length() + 1;
if (name.length() + requiredLength > MAX_FAT32_PATH_LENGTH) {
int limit = MAX_FAT32_PATH_LENGTH - requiredLength;
@@ -201,13 +201,4 @@ public class FileUtils {
return name;
}
}
-
- /**
- * Checks whether a file with the given name exists in the given directory.
- * This is isolated so it can be overridden in tests.
- */
- protected boolean fileExists(File directory, String fullName) {
- File file = new File(directory, fullName);
- return file.exists();
- }
}
diff --git a/MyTracks/src/com/google/android/apps/mytracks/util/PlayTrackUtils.java b/MyTracks/src/com/google/android/apps/mytracks/util/PlayTrackUtils.java
index 675bef4f5..2605904a5 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/util/PlayTrackUtils.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/util/PlayTrackUtils.java
@@ -24,7 +24,6 @@ import android.app.AlertDialog;
import android.app.Dialog;
import android.content.Context;
import android.content.DialogInterface;
-import android.content.DialogInterface.OnClickListener;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.content.pm.ResolveInfo;
@@ -96,7 +95,7 @@ public class PlayTrackUtils {
.setCancelable(true)
.setMessage(R.string.track_list_play_install_earth_message)
.setNegativeButton(android.R.string.cancel, null)
- .setPositiveButton(android.R.string.ok, new OnClickListener() {
+ .setPositiveButton(android.R.string.ok, new DialogInterface.OnClickListener() {
@Override
public void onClick(DialogInterface dialog, int which) {
Intent intent = new Intent();
diff --git a/MyTracks/src/com/google/android/apps/mytracks/util/SystemUtils.java b/MyTracks/src/com/google/android/apps/mytracks/util/SystemUtils.java
index c45c88308..b0dc284d6 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/util/SystemUtils.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/util/SystemUtils.java
@@ -1,12 +1,12 @@
/*
* Copyright 2011 Google Inc.
- *
+ *
* Licensed under the Apache License, Version 2.0 (the "License"); you may not
* use this file except in compliance with the License. You may obtain a copy of
* the License at
- *
+ *
* http://www.apache.org/licenses/LICENSE-2.0
- *
+ *
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
* WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
@@ -22,7 +22,6 @@ import android.content.Context;
import android.content.pm.PackageInfo;
import android.content.pm.PackageManager;
import android.content.pm.PackageManager.NameNotFoundException;
-import android.content.pm.Signature;
import android.os.PowerManager;
import android.os.PowerManager.WakeLock;
import android.util.Log;
@@ -34,26 +33,6 @@ import android.util.Log;
*/
public class SystemUtils {
- private static final int RELEASE_SIGNATURE_HASHCODE = -1855564782;
-
- /**
- * Returns whether or not this is a release build.
- */
- public static boolean isRelease(Context context) {
- try {
- Signature [] sigs = context.getPackageManager().getPackageInfo(
- context.getPackageName(), PackageManager.GET_SIGNATURES).signatures;
- for (Signature sig : sigs) {
- if (sig.hashCode() == RELEASE_SIGNATURE_HASHCODE) {
- return true;
- }
- }
- } catch (NameNotFoundException e) {
- Log.e(Constants.TAG, "Unable to get signatures", e);
- }
- return false;
- }
-
/**
* Get the My Tracks version from the manifest.
*
diff --git a/MyTracksTest/src/com/google/android/apps/mytracks/util/FileUtilsTest.java b/MyTracksTest/src/com/google/android/apps/mytracks/util/FileUtilsTest.java
index 8adda2946..12152c3c7 100644
--- a/MyTracksTest/src/com/google/android/apps/mytracks/util/FileUtilsTest.java
+++ b/MyTracksTest/src/com/google/android/apps/mytracks/util/FileUtilsTest.java
@@ -20,8 +20,6 @@ import com.google.android.apps.mytracks.Constants;
import android.os.Environment;
import java.io.File;
-import java.util.HashSet;
-import java.util.Set;
import junit.framework.TestCase;
@@ -31,76 +29,81 @@ import junit.framework.TestCase;
* @author Rodrigo Damazio
*/
public class FileUtilsTest extends TestCase {
- private FileUtils fileUtils;
- private Set existingFiles;
-
- @Override
- protected void setUp() throws Exception {
- super.setUp();
-
- existingFiles = new HashSet();
- fileUtils = new FileUtils() {
- @Override
- protected boolean fileExists(File directory, String fullName) {
- return existingFiles.contains(fullName);
- }
- };
- }
+ /**
+ * Tests {@link FileUtils#buildExternalDirectoryPath(String...)}.
+ */
public void testBuildExternalDirectoryPath() {
- String expectedName = Environment.getExternalStorageDirectory()
- + File.separator
- + Constants.SDCARD_TOP_DIR
- + File.separator
- + "a"
- + File.separator
- + "b"
- + File.separator
+ String expectedName = Environment.getExternalStorageDirectory() + File.separator
+ + Constants.SDCARD_TOP_DIR + File.separator + "a" + File.separator + "b" + File.separator
+ "c";
-
- String dirName = fileUtils.buildExternalDirectoryPath("a", "b", "c");
+ String dirName = FileUtils.buildExternalDirectoryPath("a", "b", "c");
assertEquals(expectedName, dirName);
}
/**
- * Tests sanitize filename.
+ * Tests {@link FileUtils#buildUniqueFileName(File, String, String)} when the
+ * file is new.
+ */
+ public void testBuildUniqueFileName_new() {
+ String filename = FileUtils.buildUniqueFileName(new File("/dir"), "Filename", "ext");
+ assertEquals("Filename.ext", filename);
+ }
+
+ /**
+ * Tests {@link FileUtils#buildUniqueFileName(File, String, String)} when the
+ * file exists already.
+ */
+ public void testBuildUniqueFileName_exist() {
+ // Expect "/default.prop" to exist on the phone/emulator
+ String filename = FileUtils.buildUniqueFileName(new File("/"), "default", "prop");
+ assertEquals("default(1).prop", filename);
+ }
+
+ /**
+ * Tests {@link FileUtils#sanitizeFileName(String)} with special characters.
+ * Verifies that they are sanitized.
*/
public void testSanitizeFileName() {
String name = "Swim\10ming-^across:/the/ pacific (ocean).";
String expected = "Swim_ming-^across_the_ pacific (ocean)_";
- assertEquals(expected, fileUtils.sanitizeFileName(name));
+ assertEquals(expected, FileUtils.sanitizeFileName(name));
}
/**
- * Tests characters in other languages, like Chinese and Russian, are allowed.
+ * Tests {@link FileUtils#sanitizeFileName(String)} with i18n characters (in
+ * Chinese and Russian). Verifies that they are allowed.
*/
public void testSanitizeFileName_i18n() {
String name = "您好-привет";
String expected = "您好-привет";
-
- assertEquals(expected, fileUtils.sanitizeFileName(name));
+ assertEquals(expected, FileUtils.sanitizeFileName(name));
}
-
+
/**
- * Tests special FAT32 characters are allowed.
+ * Tests {@link FileUtils#sanitizeFileName(String)} with special FAT32
+ * characters. Verifies that they are allowed.
*/
public void testSanitizeFileName_special_characters() {
String name = "$%'-_@~`!(){}^#&+,;=[] ";
String expected = "$%'-_@~`!(){}^#&+,;=[] ";
-
- assertEquals(expected, fileUtils.sanitizeFileName(name));
+ assertEquals(expected, FileUtils.sanitizeFileName(name));
}
/**
- * Testing collapsing multiple underscores characters.
+ * Tests {@link FileUtils#sanitizeFileName(String)} with multiple escaped
+ * characters in a row. Verifies that they are collapsed into one underscore.
*/
public void testSanitizeFileName_collapse() {
String name = "hello//there";
String expected = "hello_there";
-
- assertEquals(expected, fileUtils.sanitizeFileName(name));
+ assertEquals(expected, FileUtils.sanitizeFileName(name));
}
-
+
+ /**
+ * Tests {@link FileUtils#truncateFileName(File, String, String)}. Verifies
+ * the a long file name is truncated.
+ */
public void testTruncateFileName() {
File directory = new File("/dir1/dir2/");
String suffix = ".gpx";
@@ -109,36 +112,12 @@ public class FileUtilsTest extends TestCase {
name[i] = 'a';
}
String nameString = new String(name);
-
- String truncated = fileUtils.truncateFileName(directory, nameString, suffix);
+ String truncated = FileUtils.truncateFileName(directory, nameString, suffix);
+
for (int i = 0; i < truncated.length(); i++) {
assertEquals('a', truncated.charAt(i));
}
assertEquals(FileUtils.MAX_FAT32_PATH_LENGTH,
new File(directory, truncated + suffix).getPath().length());
}
-
- public void testBuildUniqueFileName_someExist() {
- existingFiles = new HashSet();
- existingFiles.add("Filename.ext");
- existingFiles.add("Filename(1).ext");
- existingFiles.add("Filename(2).ext");
- existingFiles.add("Filename(3).ext");
- existingFiles.add("Filename(4).ext");
-
- String filename = fileUtils.buildUniqueFileName(new File("/dir/"), "Filename", "ext");
- assertEquals("Filename(5).ext", filename);
- }
-
- public void testBuildUniqueFileName_oneExists() {
- existingFiles.add("Filename.ext");
-
- String filename = fileUtils.buildUniqueFileName(new File("/dir/"), "Filename", "ext");
- assertEquals("Filename(1).ext", filename);
- }
-
- public void testBuildUniqueFileName_noneExists() {
- String filename = fileUtils.buildUniqueFileName(new File("/dir/"), "Filename", "ext");
- assertEquals("Filename.ext", filename);
- }
}
diff --git a/MyTracks/src/com/google/android/apps/mytracks/util/DialogUtils.java b/MyTracks/src/com/google/android/apps/mytracks/util/DialogUtils.java
index c6c39cfac..126f25bf4 100644
--- a/MyTracks/src/com/google/android/apps/mytracks/util/DialogUtils.java
+++ b/MyTracks/src/com/google/android/apps/mytracks/util/DialogUtils.java
@@ -37,15 +37,15 @@ public class DialogUtils {
* Creates a confirmation dialog.
*
* @param context the context
* @param message the confirmation message
* @param onClickListener the listener to invoke when the user clicks OK
*/
public static Dialog createConfirmationDialog(
- Context context, String message, DialogInterface.OnClickListener onClickListener) {
+ Context context, int messageId, DialogInterface.OnClickListener onClickListener) {
return new AlertDialog.Builder(context)
.setCancelable(true)
.setIcon(android.R.drawable.ic_dialog_alert)
- .setMessage(message)
+ .setMessage(context.getString(messageId))
.setNegativeButton(android.R.string.cancel, null)
.setPositiveButton(android.R.string.ok, onClickListener)
.setTitle(R.string.generic_confirm_title)
@@ -56,39 +56,47 @@ public class DialogUtils {
* Creates a spinner progress dialog.
*
* @param context the context
* @param message the progress message
* @param onCancelListener the listener to invoke when the user cancels
*/
public static ProgressDialog createSpinnerProgressDialog(
- Context context, String message, DialogInterface.OnCancelListener onCancelListener) {
- ProgressDialog progressDialog = new ProgressDialog(context);
- progressDialog.setCancelable(true);
- progressDialog.setIcon(android.R.drawable.ic_dialog_info);
- progressDialog.setIndeterminate(true);
- progressDialog.setMessage(message);
- progressDialog.setOnCancelListener(onCancelListener);
- progressDialog.setProgressStyle(ProgressDialog.STYLE_SPINNER);
- progressDialog.setTitle(R.string.generic_progress_title);
- return progressDialog;
+ Context context, int messageId, DialogInterface.OnCancelListener onCancelListener) {
+ return createProgressDialog(true, context, messageId, onCancelListener);
}
-
+
/**
* Creates a horizontal progress dialog.
*
* @param context the context
* @param message the progress message
* @param onCancelListener the listener to invoke when the user cancels
*/
- public static ProgressDialog createHorizontalProgressDialog(
- Context context, String message, DialogInterface.OnCancelListener onCancelListener) {
+ public static ProgressDialog createHorizontalProgressDialog(Context context, int messageId,
+ DialogInterface.OnCancelListener onCancelListener, Object... formatArgs) {
+ return createProgressDialog(false, context, messageId, onCancelListener, formatArgs);
+ }
+
+ /**
+ * Creates a progress dialog.
+ *
+ * @param spinner true to use the spinner style
+ * @param context the context
+ * @param messageId the progress message id
+ * @param onCancelListener the cancel listener
+ * @param formatArgs the format arguments for the message id
+ */
+ private static ProgressDialog createProgressDialog(boolean spinner, Context context,
+ int messageId, DialogInterface.OnCancelListener onCancelListener, Object... formatArgs) {
ProgressDialog progressDialog = new ProgressDialog(context);
progressDialog.setCancelable(true);
progressDialog.setIcon(android.R.drawable.ic_dialog_info);
progressDialog.setIndeterminate(true);
- progressDialog.setMessage(message);
+ progressDialog.setMessage(context.getString(messageId, formatArgs));
progressDialog.setOnCancelListener(onCancelListener);
- progressDialog.setProgressStyle(ProgressDialog.STYLE_HORIZONTAL);
- progressDialog.setTitle(R.string.generic_progress_title);
+ progressDialog.setProgressStyle(spinner ? ProgressDialog.STYLE_SPINNER
+ : ProgressDialog.STYLE_HORIZONTAL);
+ progressDialog.setTitle(R.string.generic_progress_title);
return progressDialog;
}
}
@@ -37,15 +37,15 @@ public class DialogUtils {
*
* @param context the context
- * @param message the confirmation message
+ * @param messageId the confirmation message id
* @param onClickListener the listener to invoke when the user clicks OK
*/
@@ -56,39 +56,47 @@ public class DialogUtils {
*
* @param context the context
- * @param message the progress message
- * @param onCancelListener the listener to invoke when the user cancels
+ * @param messageId the progress message id
+ * @param onCancelListener the cancel listener
*/
public static ProgressDialog createSpinnerProgressDialog(
@@ -56,39 +56,47 @@ public class DialogUtils {
*
* @param context the context
- * @param message the progress message
- * @param onCancelListener the listener to invoke when the user cancels
+ * @param messageId the progress message id
+ * @param onCancelListener the cancel listener
+ * @param formatArgs the format arguments for the messageId
*/